.. |travis-ci| image:: https://secure.travis-ci.org/mig33/holmium.core.png
    :target: https://travis-ci.org/#!/mig33/holmium.core 

Development
===========
.. _github: http://github.com/mig33/holmium.core/
.. _issue tracker: http://github.com/mig33/holmium.core/issues

Contributors
~~~~~~~~~~~~
.. include:: ../../CONTRIBUTORS.rst

Project Resources
~~~~~~~~~~~~~~~~~
Continuous Integration
    The project is being continuously built with Travis-CI against python 2.6 & 2.7. |travis-ci|

Code
    The code is hosted on `github`_.

Bugs, Feature Requests
    Tracked at the `issue tracker`_.


